summary refs log tree commit diff
path: root/synapse/util/caches
diff options
context:
space:
mode:
authorAdrian Tschira <nota@notafile.com>2018-05-24 20:52:56 +0200
committerAdrian Tschira <nota@notafile.com>2018-05-24 20:55:08 +0200
commitdd068ca9792e7f4a51690b91262131b5dae80455 (patch)
tree3a979667f0fc25653d3eb428bec23f4832085a4e /synapse/util/caches
parentMerge pull request #3278 from NotAFile/py3-storage-base (diff)
downloadsynapse-dd068ca9792e7f4a51690b91262131b5dae80455.tar.xz
remaining isintance fixes
Signed-off-by: Adrian Tschira <nota@notafile.com>
Diffstat (limited to 'synapse/util/caches')
-rw-r--r--synapse/util/caches/descriptors.py12
1 files changed, 8 insertions, 4 deletions
diff --git a/synapse/util/caches/descriptors.py b/synapse/util/caches/descriptors.py
index 68285a7594..b595cd6164 100644
--- a/synapse/util/caches/descriptors.py
+++ b/synapse/util/caches/descriptors.py
@@ -31,6 +31,9 @@ import functools
 import inspect
 import threading
 
+from six import string_types, itervalues
+import six
+
 
 logger = logging.getLogger(__name__)
 
@@ -205,7 +208,7 @@ class Cache(object):
     def invalidate_all(self):
         self.check_thread()
         self.cache.clear()
-        for entry in self._pending_deferred_cache.itervalues():
+        for entry in itervalues(self._pending_deferred_cache):
             entry.invalidate()
         self._pending_deferred_cache.clear()
 
@@ -392,9 +395,10 @@ class CacheDescriptor(_CacheDescriptorBase):
 
                 ret.addErrback(onErr)
 
-                # If our cache_key is a string, try to convert to ascii to save
-                # a bit of space in large caches
-                if isinstance(cache_key, basestring):
+                # If our cache_key is a string on py2, try to convert to ascii
+                # to save a bit of space in large caches. Py3 does this
+                # internally automatically.
+                if six.PY2 and isinstance(cache_key, string_types):
                     cache_key = to_ascii(cache_key)
 
                 result_d = ObservableDeferred(ret, consumeErrors=True)